Changelog
=========

v0.1.8
------

- Prevent failure in case the ``TERM`` environment variable is not set (PR #1)

v0.1.7
------

- Added support for ``message_inline`` argument. If set to ``False``,
  messages will be displayed on their own line (useful when enabling a lot of
  information)

v0.1.6
------

- Added support for showing more information:

  - record date
  - file name / line number
  - module / function

v0.1.5
------

- Added support for nicer colors in 256-color mode
- Removed dependency from termcolor (now shipping better implementation)
